//----------------------------------------------------------------------------
//
// Copyright (C) Sartorius Stedim Data Analytics AB 2017 -
//
// Use, modification and distribution are subject to the Boost Software
// License, Version 1.0. (See http://www.boost.org/LICENSE_1_0.txt)
//
//----------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using SIMCAQLib;

namespace SQPCSharpSample
{
   public partial class Form1 : Form
   {
      EzQ ezQ = new EzQ();

      public Form1()
      {
         InitializeComponent();
      }

      private void button1_Click(object sender, EventArgs e)
      {
         if (openFileDialog1.ShowDialog() == DialogResult.OK)
         {
            try
            {
               if (!ezQ.OpenProject(openFileDialog1.FileName, null))
                  throw new System.Exception(ezQ.LastErrorMessage);

               ezQ.SelectModel(1);

               // Create a fake prediction set
               long lPredictions = ((VariableVector)((PreparePrediction)ezQ.Model.PreparePrediction()).GetVariablesForPrediction()).GetSize();
               float[] predSet = new float[lPredictions];
               for (int i = 0; i < predSet.Length; ++i)
                  predSet[i] = i;

               ezQ.Predict(predSet, 1, predSet.Length, null, 0, 0);

               // Output the result
               VectorData result = ezQ.GetDModXPS();
               if (result.GetDataMatrix() != null)
                  lblDModX.Text = String.Format("{0}", ((FloatMatrix)result.GetDataMatrix()).GetData(1, 1));
               result = ezQ.GetT2RangePS();
               if (result.GetDataMatrix() != null)
                  lblHotellings.Text = String.Format("{0}", ((FloatMatrix)result.GetDataMatrix()).GetData(1, 1));

               ezQ.CloseProject();
            }
            catch (System.Exception ex)
            {
               MessageBox.Show(String.Format("An error occured while processing the project:\n\n{0}", ex.Message), this.Text);

               lblDModX.Text = "N/A";
               lblHotellings.Text = "N/A";

               ezQ.CloseProject();
            }
         }
      }

      private void button2_Click(object sender, EventArgs e)
      {
         Close();
      }
   }
}